( cd usr/lib/epiphany/extensions ; rm -rf libcertificatesextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf libcertificatesextension.so.0.0.0 libcertificatesextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf libcertificatesextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf libcertificatesextension.so.0.0.0 libcertificatesextension.so.0 )
( cd usr/lib/epiphany/extensions ; rm -rf libdashboardextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf libdashboardextension.so.0.0.0 libdashboardextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf libdashboardextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf libdashboardextension.so.0.0.0 libdashboardextension.so.0 )
( cd usr/lib/epiphany/extensions ; rm -rf liberrorviewerextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf liberrorviewerextension.so.0.0.0 liberrorviewerextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf liberrorviewerextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf liberrorviewerextension.so.0.0.0 liberrorviewerextension.so.0 )
( cd usr/lib/epiphany/extensions ; rm -rf libgesturesextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf libgesturesextension.so.0.0.0 libgesturesextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf libgesturesextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf libgesturesextension.so.0.0.0 libgesturesextension.so.0 )
( cd usr/lib/epiphany/extensions ; rm -rf libpopupblockerextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf libpopupblockerextension.so.0.0.0 libpopupblockerextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf libpopupblockerextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf libpopupblockerextension.so.0.0.0 libpopupblockerextension.so.0 )
( cd usr/lib/epiphany/extensions ; rm -rf libtabsmenuextension.so )
( cd usr/lib/epiphany/extensions ; ln -sf libtabsmenuextension.so.0.0.0 libtabsmenuextension.so )
( cd usr/lib/epiphany/extensions ; rm -rf libtabsmenuextension.so.0 )
( cd usr/lib/epiphany/extensions ; ln -sf libtabsmenuextension.so.0.0.0 libtabsmenuextension.so.0 )
